using System;
using System.Runtime.InteropServices;
using System.ComponentModel;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Drawing;
using System.Drawing.Printing;

namespace SLPrinter
{
    [
        Guid("10fa4755-61d3-48b1-bf32-860e097e9d19"),
        InterfaceType(ComInterfaceType.InterfaceIsIDispatch),
        ComVisible(true)
    ]
    public interface iSLPrinter
    {

        [DispId(1)]
        bool SetSLPPrinter(string sDefaultPrinter);

        [DispId(2)]
        bool SetToDefaultPrinter(string sDefaultPrinter);

        [DispId(3)]
        void SLPPrint(string CustNumber, string CustName, string sFont, float FontSize);

        [DispId(4)]
        void About();

        //[DispId(5)]
        //string CustomerName {get;set;}

        //[DispId(6)]
        //string fontName {get;set;}

        //[DispId(7)]
        //float fontSize {get;set;}
    }

    [
        Guid("3cebef3e-577e-42d2-a89c-7b83c073c2c4"),

    // This is basically the programmer friendly name
        // for the guid above. We define this because it will
        // be used to instantiate this class. I think this can be
        // whatever you want. Generally it is
        // [assemblyname].[classname]
        ProgId("ClientSidePrinter.SLPrinter"),

    // No class interface is generated for this class and
        // no interface is marked as the default.
        // Users are expected to expose functionality through
        // interfaces that will be explicitly exposed by the object
        // This means the object can only expose interfaces we define
        ClassInterface(ClassInterfaceType.None),

    // Set the default COM interface that will be used for
        // Automation. Languages like: C#, C++ and VB
        // allow to query for interface's we're interested in
        // but Automation only aware languages like javascript do
        // not allow to query interface(s) and create only the
        // default one
        ComDefaultInterface(typeof(iSLPrinter)),
        ComVisible(true)
    ]
    public class clsSLPrinter : IObjectSafetyImpl, iSLPrinter
    {
        #region [iSLPrinter implementation]
        string CustomerName, CustomerNumber, fontName;
        float fontSize;
        public bool SetSLPPrinter(string sDefaultPrinter)
        {
            foreach (String printer in PrinterSettings.InstalledPrinters)
            {
                string sLabelPrinter;
                if (printer.ToUpper().Contains("LABEL"))
                {
                    sLabelPrinter = printer;
                }
            }
            return true;
        }

        public void About()
        {
            MessageBox.Show("An In-house developed dll for printing to label printer");
        }
        public bool SetToDefaultPrinter(string sDefaultPrinter)
        {
            return true;
        }

        public void SLPPrint(string CustNumber, string CustName, string sFont, float FontSize)
        {
            PrintDocument pc = new PrintDocument();
            PrintDocument pd = new PrintDocument();
            try
            {
                string sPrinterName = "";

                CustomerNumber = CustNumber;
                CustomerName = CustName;
                fontName = sFont;
                fontSize = FontSize;
                foreach (string printerName in PrinterSettings.InstalledPrinters)
                {
                    if (printerName.ToUpper().Contains("LABEL"))
                    {
                        sPrinterName = printerName;
                        break;
                    }
                }

                if (sPrinterName != "")
                {
                    pd.PrinterSettings.PrinterName = sPrinterName;
                    foreach (PaperSize ps in pd.PrinterSettings.PaperSizes)
                    {
                        //this.listBox1.Items.Add(ps.PaperName);
                        if (ps.PaperName.ToUpper().Contains("SLP-SRL"))
                        {
                            pd.DefaultPageSettings.PaperSize = ps;
                            break;
                        }
                    }
                    pd.DefaultPageSettings.Landscape = true;
                    //MessageBox.Show("Before the Event");
                    pd.PrintPage += new PrintPageEventHandler
                       (this.pd_PrintPage);
                    pd.Print();

                }
                else
                {
                    MessageBox.Show("No label Printer found");
                }
            }
            catch (Exception Ex)
            {
                MessageBox.Show(Ex.Message);
                //return false;
            }
            finally
            {
                pc.Dispose();
                pd.Dispose();
            }
        }
        private void pd_PrintPage(object sender, PrintPageEventArgs ev)
        {
            Font fontBC;
            Font fontArial;
            float y = 0;
            fontBC = new Font("3 of 9 Barcode", 18);
            fontArial = new Font("Arial", 11);
            ev.Graphics.DrawString("*" + CustomerName + "*", fontBC, Brushes.Black, 0, y);
            y = y + fontBC.GetHeight(ev.Graphics);
            y = y - 1;
            ev.Graphics.DrawString("*" + CustomerName + "*", fontBC, Brushes.Black, 0, y);
            y = y + fontBC.GetHeight(ev.Graphics) + 10;
            ev.Graphics.DrawString(CustomerName, fontArial, Brushes.Black, 0, y);
            y = y + fontArial.GetHeight(ev.Graphics) + 10;
            ev.Graphics.DrawString("*" + CustomerNumber + "*", fontBC, Brushes.Black, 0, y);
            y = y + fontBC.GetHeight(ev.Graphics);
            y = y - 1;
            ev.Graphics.DrawString("*" + CustomerNumber + "*", fontBC, Brushes.Black, 0, y);
            y = y + 10 + fontBC.GetHeight(ev.Graphics);
            ev.Graphics.DrawString(CustomerNumber, fontArial, Brushes.Black, 0, y);
        }
        #endregion
    }
}
